Index: /FCKeditor/trunk/editor/_source/commandclasses/fckindentcommands.js
===================================================================
--- /FCKeditor/trunk/editor/_source/commandclasses/fckindentcommands.js	(revision 929)
+++ /FCKeditor/trunk/editor/_source/commandclasses/fckindentcommands.js	(revision 930)
@@ -178,5 +178,5 @@
 				currentOffset = Math.max( currentOffset, 0 ) ;
 				currentOffset = Math.ceil( currentOffset / this.Offset ) * this.Offset ;
-				block.style[this.IndentCSSProperty] = currentOffset ? currentOffset + 'px' : '' ;
+				block.style[this.IndentCSSProperty] = currentOffset ? currentOffset + FCKConfig.IndentUnit : '' ;
 				if ( block.getAttribute( 'style' ) == '' )
 					block.removeAttribute( 'style' ) ;
Index: /FCKeditor/trunk/fckconfig.js
===================================================================
--- /FCKeditor/trunk/fckconfig.js	(revision 929)
+++ /FCKeditor/trunk/fckconfig.js	(revision 930)
@@ -60,9 +60,10 @@
 FCKConfig.ContentLangDirection	= 'ltr' ;
 
-// The distance of an indentation step, in pixels.
+// The distance of an indentation step.
 FCKConfig.IndentLength = 40 ;
+FCKConfig.IndentUnit = 'px' ;
 
 // Alternatively, FCKeditor allows the use of CSS classes for block indentation.
 // This overrides the IndentLength setting.
 FCKConfig.IndentClasses = [] ;
 
@@ -60,9 +60,10 @@
 
 // Alternatively, FCKeditor allows the use of CSS classes for block indentation.
-// This overrides the IndentLength setting.
+// This overrides the IndentLength/IndentUnit settings.
 FCKConfig.IndentClasses = [] ;
 
